/** @typedef {(metrics: object) => void} ApiReporter */
/**
 * Create API reporter function, that accepts object and sends it to `url`
 * using `navigator.sendBeackon` when avaiable or fallbacks back to XMLHttpRequest.
 *
 * The function is debounced by default, so it can acummulate object values
 * and send every `wait` time or `maxWait` if the events keep coming.
 *
 * Use `onSend` argument to implement a custom logic.
 *
 * @param {string} url
 * @param {{ wait?: number, maxWait?: number, sessionId?: string, onSend?: function }} [opts]
 * @return {ApiReporter}
 */
export function createApiReporter(url: string, opts?: {
    wait?: number | undefined;
    maxWait?: number | undefined;
    sessionId?: string | undefined;
    onSend?: Function | undefined;
} | undefined): (metrics: any) => void;
export type ApiReporter = (metrics: any) => void;
